@@ -17,14 +17,20 @@ async def get_version_impl(info):
     regex = re.compile(conf['regex'])
   except sre_constants.error as e:
     raise GetVersionError('bad regex', exc_info=e)
+  if regex.groups > 1:
+    raise GetVersionError('multi-group regex')
 
   encoding = conf.get('encoding', 'latin1')
 
-  res = await session.get(conf['url'])
+  data = conf.get('post_data')
+  if data is None:
+    res = await session.get(conf['url'])
+  else:
+    res = await session.post(conf['url'], body = data, headers = {
+        'Content-Type': conf.get('post_data_type', 'application/x-www-form-urlencoded')
+      })
   body = res.body.decode(encoding)
-  try:
-    version = regex.findall(body)
-  except ValueError:
-    if not conf.get('missing_ok', False):
-      raise GetVersionError('version string not found.')
-  return version
+  versions = regex.findall(body)
+  if not versions and not conf.get('missing_ok', False):
+    raise GetVersionError('version string not found.')
+  return versions
